NAME
Sisimai::Reason::HasMoved - Bounce reason is hasmoved or not.
SYNOPSIS
use Sisimai::Reason::HasMoved;
print Sisimai::Reason::HasMoved->match('address neko@example.jp has been replaced by ...'); # 1
DESCRIPTION
Sisimai::Reason::HasMoved checks the bounce reason is hasmoved or not. This class is called only Sisimai::Reason class.
CLASS METHODS
text()
text() returns string: systemfull.
print Sisimai::Reason::HasMoved->text; # hasmoved
match( string )
match() returns 1 if the argument matched with patterns defined in this class.
print Sisimai::Reason::HasMoved->match('address cat@example.jp has been replaced by '); # 1
true( Sisimai::Data )
true() returns 1 if the bounce reason is hasmoved. The argument must be Sisimai::Data object and this method is called only from Sisimai::Reason class.
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2015 azumakuniyuki <perl.org@azumakuniyuki.org>, All Rights Reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.